@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/TestUtils.pm $
-#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#     $Date: 2008-03-08 10:09:46 -0600 (Sat, 08 Mar 2008) $
 #   $Author: clonezone $
-# $Revision: 2018 $
+# $Revision: 2163 $
 ##############################################################################
 
 package Perl::Critic::TestUtils;
@@ -11,7 +11,6 @@ use strict;
 use warnings;
 use English qw(-no_match_vars);
 use Readonly;
-use Carp qw( confess );
 
 use base 'Exporter';
 
@@ -23,10 +22,13 @@ use File::Find qw( find );
 
 use Perl::Critic;
 use Perl::Critic::Config;
+use Perl::Critic::Exception::Fatal::Generic qw{ &throw_generic };
+use Perl::Critic::Exception::Fatal::Internal qw{ &throw_internal };
 use Perl::Critic::Utils qw{ :severities :data_conversion policy_long_name };
 use Perl::Critic::PolicyFactory (-test => 1);
 
-our $VERSION = '1.080';
+our $VERSION = '1.082';
+
 Readonly::Array our @EXPORT_OK => qw(
     pcritique pcritique_with_violations
     critique  critique_with_violations
@@ -106,15 +108,16 @@ sub fcritique_with_violations {
     my $file = File::Spec->catfile($dir, @fileparts);
     if (open my $fh, '>', $file) {
         print {$fh} ${$code_ref};
-        close $fh or confess "unable to close $file: $!";
+        close $fh or throw_generic "unable to close $file: $!";
     }
 
-    # Use eval so we can clean up before die() in case of error.
+    # Use eval so we can clean up before throwing an exception in case of
+    # error.
     my @v = eval {$c->critique($file)};
     my $err = $EVAL_ERROR;
     File::Path::rmtree($dir, 0, 1);
     if ($err) {
-        confess $err;
+        throw_generic $err;
     }
     return @v;
 }
@@ -138,7 +141,7 @@ sub subtests_in_tree {
                return if !$fileroot;
                my @pathparts = File::Spec->splitdir($fileroot);
                if (@pathparts < 2) {
-                   confess 'confusing policy test filename ' . $_;
+                   throw_internal 'confusing policy test filename ' . $_;
                }
                my $policy = join q{::}, @pathparts[-2, -1]; ## no critic (MagicNumbers)
 
@@ -180,7 +183,7 @@ sub _subtests_from_file {
     return if -z $test_file;  # Skip if the Policy has a regular .t file.
 
     open my $fh, '<', $test_file   ## no critic (RequireBriefOpen)
-      or confess "Couldn't open $test_file: $OS_ERROR";
+      or throw_internal "Couldn't open $test_file: $OS_ERROR";
 
     my @subtests;
 
@@ -195,11 +198,13 @@ sub _subtests_from_file {
         my $line = $_;
 
         if ( $inheader ) {
-            $line =~ m/\A [#]/mx or confess "Code before cut: $test_file";
+            $line =~ m/\A [#]/mx or throw_internal "Code before cut: $test_file";
             my ($key,$value) = $line =~ m/\A [#][#] [ ] (\S+) (?:\s+(.+))? /mx;
             next if !$key;
             next if $key eq 'cut';
-            confess "Unknown key $key in $test_file" if !$valid_keys{$key};
+            if ( not $valid_keys{$key} ) {
+                throw_internal "Unknown key $key in $test_file";
+            }
 
             if ( $key eq 'name' ) {
                 if ( $subtest ) { # Stash any current subtest
@@ -210,7 +215,7 @@ sub _subtests_from_file {
                 $incode = 0;
             }
             if ($incode) {
-                confess "Header line found while still in code: $test_file";
+                throw_internal "Header line found while still in code: $test_file";
             }
             $subtest->{$key} = $value;
         }
@@ -221,16 +226,16 @@ sub _subtests_from_file {
         }
         elsif (@subtests) {
             ## don't complain if we have not yet hit the first test
-            confess "Got some code but I'm not in a subtest: $test_file";
+            throw_internal "Got some code but I'm not in a subtest: $test_file";
         }
     }
-    close $fh or confess "unable to close $test_file: $!";
+    close $fh or throw_generic "unable to close $test_file: $!";
     if ( $subtest ) {
         if ( $incode ) {
             push @subtests, _finalize_subtest( $subtest );
         }
         else {
-            confess "Incomplete subtest in $test_file";
+            throw_internal "Incomplete subtest in $test_file";
         }
     }
 
@@ -244,19 +249,21 @@ sub _finalize_subtest {
         $subtest->{code} = join "\n", @{$subtest->{code}};
     }
     else {
-        confess "$subtest->{name} has no code lines";
+        throw_internal "$subtest->{name} has no code lines";
     }
     if ( !defined $subtest->{failures} ) {
-        confess "$subtest->{name} does not specify failures";
+        throw_internal "$subtest->{name} does not specify failures";
     }
     if ($subtest->{parms}) {
         $subtest->{parms} = eval $subtest->{parms}; ## no critic(StringyEval)
         if ($EVAL_ERROR) {
-            confess "$subtest->{name} has an error in the 'parms' property:\n"
-              . $EVAL_ERROR;
+            throw_internal
+                "$subtest->{name} has an error in the 'parms' property:\n"
+                  . $EVAL_ERROR;
         }
         if ('HASH' ne ref $subtest->{parms}) {
-            confess "$subtest->{name} 'parms' did not evaluate to a hashref";
+            throw_internal
+                "$subtest->{name} 'parms' did not evaluate to a hashref";
         }
     } else {
         $subtest->{parms} = {};
@@ -266,7 +273,8 @@ sub _finalize_subtest {
         if ( $subtest->{error} =~ m{ \A / (.*) / \z }xms) {
             $subtest->{error} = eval {qr/$1/}; ##no critic (RegularExpressions::)
             if ($EVAL_ERROR) {
-                confess "$subtest->{name} 'error' has a malformed regular expression";
+                throw_internal
+                    "$subtest->{name} 'error' has a malformed regular expression";
             }
         }
     }
@@ -303,7 +311,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::TestUtils - Utility functions for testing new Policies
+Perl::Critic::TestUtils - Utility functions for testing new Policies.
 
 =head1 SYNOPSIS
 
@@ -513,7 +521,7 @@ and the rest of the L<Perl::Critic> team.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2007 Chris Dolan.  All rights reserved.
+Copyright (c) 2005-2008 Chris Dolan.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
